package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````H"(``#0````XL0```````#0`(``-
M`"@`'``;``8````T````-````#0```"@`0``H`$```0````$`````P```"`"
M```@`@``(`(``!,````3````!`````$````!````````````````````\!$`
M`/`1```$`````!````$`````(````"`````@```\-0``/#4```4`````$```
M`0````!@````8````&```'Q'``!\1P``!``````0```!````O*T``+R]``"\
MO0``7`(``'`"```&`````!````(```#$K0``Q+T``,2]```@`0``(`$```8`
M```$````!````-0!``#4`0``U`$``$P```!,````!`````0````$````7*<`
M`%RG``!<IP``(````"`````$````!````%/E=&3X`0``^`$``/@!```H````
M*`````0````$````4.5T9'"@``!PH```<*```!P!```<`0``!`````0```!1
MY71D```````````````````````````&````$````%+E=&2\K0``O+T``+R]
M``!$`@``1`(```0````!````!````!0````#````1TY5`"=)RM4C<I]'WC</
M.XP%5!`=V7^K!````!@````%````1TY5``$``<`$`````0````(``<`$````
M`````"]L:6(O;&0M;&EN=7@N<V\N,@``*P```$4````(````"``````0$`0E
M0`2`*`$`!:"&`(2`@0`""R@$"#B`$D&*```(10``````````````1@``````
M````````1P````````!(````20````````!*`````````$P`````````````
M`$T```!.`````````%````!1````4P````````!4````50```%8`````````
M`````````````````````%<```!8````60```%H```!;``````````````!=
M`````````%X``````````````(D'<--K&IY0H^#[29E/PYOC1\8!9J_,9D-%
MU>R[XY)\LP&+;UCH[>QOQ=\?%8PES"[%F[9K"4/6(?_D#ONA;&##Y3\L#3J7
M"\_>1RW9<5@<?ZF<F^&G`@I"^M>':W^:?#-BV^W49-1\K4OCP```````````
M``````````#``@`````````````2````'`(`````````````$@````<"````
M`````````!(```!Q```````````````2````>P``````````````$@```(H!
M`````````````!(```#+`0`````````````2````4`(`````````````$@``
M`(<``````````````!(````!```````````````@````+`(`````````````
M$@```)4"`````````````!(```#C`@`````````````2````N0``````````
M````$@```&$``````````````!(```#G```````````````2````^@$`````
M````````$@```-(!`````````````!(```#U`0`````````````2````$```
M````````````(````-P``````````````!(```!V```````````````2````
MJP(`````````````$@```"P``````````````"````!?`@`````````````2
M````#0(`````````````$@```)P"`````````````!(```!3````````````
M```2````)P$`````````````%@````0!`````````````!(```!J`0``````
M```````2````J```````````````$@```/4``````````````!(```"Q`0``
M```````````2````>`(`````````````$0```+("`````````````!(```#H
M`0`````````````2````V@$`````````````$@```*(#`````````````!(`
M``#-```````````````2````I`(`````````````$@```-L"````````````
M`!$```#"`0`````````````2````F@``````````````$@```"`!````````
M`````!(```!>`0`````````````2````]0(`````````````$@```.\!````
M`````````!(```#A`0`````````````2````7@(`````````````$@```","
M`````````````!(````Z`0`````````````2````%`$`````````````$@``
M`#0"`````````````!(```#9`@`````````````1````?P(`````````````
M$@```-$"`````````````!(```!&```````````````1````3P$`````````
M````$0```,(``````````````!(```!"`@`````````````2````>P$`````
M````````$@```+L!`````````````!(```!F`@`````````````2````J0$`
M````````````$@```+D"`````````````!(```"&`@`````````````B````
MI`$`````````````$@```"0$```4P```!````!$`&`"&`P``T%(``!`"```2
M``X`-@0````P```O!```$@`.`"X$``"0-```-@```!(`#@`L`P``0"X``#H`
M```2``X`>@,``(`N``!T`0``$@`.`/X#```8P````````!``&`#L`P``+,``
M```````0`!D`5@,``#`T``!9````$@`.`#D#````8```!````!$`$`"K`P``
MD$$``,L````2``X`XP,``(!0``!1````$@`.`!L#``#0*P``!0```!(`#@"W
M`P```,`````````0`!@`%P0``.`K``!7`@``$@`.``4$``#0-@``V0```!(`
M#@#/`P``L"H``#@````2``X`N0,```#`````````(``8`/$#``"P-P``J@<`
M`!(`#@#7`P``&,`````````0`!D`D`,``*`V```P````$@`.`&0#``#P*@``
MV@```!(`#@#$`P``X%```.0!```2``X`<P(``$`@``!5`@``$@`.`+T#``"@
M(@``+````!(`#@!``P``8#\``"4"```2``X`E0$```1@```$````$0`0``!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U;F1U;7``4&5R;%]S>7-?
M=&5R;0!097)L7V=V7V9E=&-H<'8`<&5R;%]F<F5E`%!E<FQ?9V5T7W-V`%!E
M<FQ?871F;W)K7W5N;&]C:P!P97)L7V1E<W1R=6-T`%!E<FQ?;F5W6%-?9FQA
M9W,`<&5R;%]R=6X`4&5R;%]N97=84P!097)L7W-V7W-E='!V;@!P97)L7V%L
M;&]C`%!E<FQ?<W9?<V5T<'8`<&5R;%]C;VYS=')U8W0`8F]O=%]$>6YA3&]A
M9&5R`%!E<FQ?<V%F97-Y<VUA;&QO8P!03%]C=7)R96YT7V-O;G1E>'0`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4$Q?;65M;W)Y7W=R87``4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?;&]C:P!097)L7W-Y<U]I;FET,P!P97)L7W!A<G-E`%])
M3U]S=&1I;E]U<V5D`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L
M;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!S=')T;VL`<W1R;&5N`')M
M9&ER`')E860`7U]M96UC<'E?8VAK`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E
M='!I9`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]M96UM;W9E
M7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`
M<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;W!E;F1I<@!G
M971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!S
M=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`&QI8G!E<FPN<V\`;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A
M<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U
M<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?
M:6YI=%]E;G8`1TQ)0D-?04))7T147U)%3%(`1TQ)0D-?,BXQ+C,`1TQ)0D-?
M,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXR`$=,24)#7S(N,S,`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXQ`$=,24)#7S(N,``O=7-R+VQI8B]P
M97)L-2\U+C0P+V-O<F5?<&5R;"]#3U)%`````@`"``(``0`!``$``P`$``$`
M`0`"``(`!0`!``$``0`$``(``@`!``$``@`"``$`!@`$``(``0`!``$``0`!
M``$`!P`"``(``@`"``(``0`"``(``@`!``(``0`(``(``@`&``(``0`!``0`
M`@`"``(``0`!``$`!``!``(`"0`#``(`"@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`*`!$#
M```0`````````$(._0````L`0P0``!````!S'VD)```*`%4$```0````M)&6
M!@``"0!A!```$````!1I:0T```@`;`0``!`````2:6D-```'`'8$```0````
MLY&6!@``!@"`!```$````'(9:0D```4`BP0``!````!T&6D)```$`)<$```0
M````$6EI#0```P"C!```$````!!I:0T```(`K00```````#TO@``!@$``/B^
M```&`@``_+X```8#````OP``!@0```2_```&!0``"+\```8&```,OP``!@<`
M`!"_```&"```%+\```8)```8OP``!@H``!R_```&"P``(+\```8,```DOP``
M!@T``"B_```&#@``++\```8/```POP``!A```#2_```&$0``.+\```82```\
MOP``!A,``$"_```&%```1+\```85``!(OP``!A8``$R_```&%P``4+\```88
M``!4OP``!AD``%B_```&&@``7+\```8;``!@OP``!AP``&2_```.'0``:+\`
M``8>``!LOP``!A\``'"_```&(```=+\```8A``!XOP``!B(``'R_```&(P``
M@+\```8D``"$OP``!B4``(B_```&)@``C+\```8G``"0OP``!B@``)2_```&
M*0``F+\```8J``"<OP``!BL``*"_```&+```I+\```8M``"HOP``!BX``*R_
M```&+P``L+\```8P``"TOP``!C$``+B_```&,@``O+\```8S``#`OP``!C0`
M`,2_```&-0``R+\```8V``#,OP``!C@``-"_```&.0``U+\```8Z``#8OP``
M!CL``-R_```&/```X+\```8]``#DOP``!CX``.B_```&/P``[+\```9!``#P
MOP``!D(``/2_```&0P``^+\```9$``#PO@``!T```+R]```#````_+\``$4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z,<"``"!P]N>``"+@S0```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@____C4PD!(/D\/]Q_%6)Y5>)SU93Z'D"``"!
MPXV>``!1@^PLBT$$B474BT$(B4709:$4````B47DC4704(U%U%!1_Y,``0``
MBX,P````@\0,4%#_LX@```!GZ$0T``"+@_````"#Q!"`.``/A"<!``"+@X``
M``!EBP"`B*("```#BP>-<`.#P`2)=<P]____/P^'A@$``(/L#,'@`E#_D^``
M``"+==2+/XG!B8-``0``BP:#Q!")`8V#!Z/__XE!!(N#,`$``(E!"(V#"J/_
M_XE!#(/_`0^.8@$``(E-R(U&!(U1$(TTOBZ-M"8`````C78`BPB#P`2#P@2)
M2OPYQG7QBTW(@\<#@^P,C8-L:___QP2Y`````&H`4?]US%#_LT0!``#_DR0`
M``"#Q""%P`^$F````(/L#/^S1`$``(U]X/^3O````(GZB<:-@\.A___H3`(`
M`(/$$(7`#X2#````@^P,_[-$`0``_Y,<````@\00_Y-\````BT7D92L%%```
M``^%R0```(UE\(GP65M>7UV-8?S#_Y-@````B8-$`0``A<`/A)P```"#[`Q0
M_Y.0````BX.`````98L0@\00QH(Z!0```.FI_O__@^P,_[-$`0``_Y-$````
M@\00Z5'___^+@SP!``"%P'01@^P,4.A;'P``@\00Z6+___^)^HV#>*'__^B6
M`0``B8,\`0``A<`/A$?____KTHM%Y&4K!10```!U*E!0C8-SH?___[/T````
M4/^3W````+\$````Z<#^__^#[`QJ`?^3%`$``.A[,@``9I!FD&:09I!FD)`Q
M[5Z)X8/D\%!44N@8````@<,TG```:@!J`%%6_[,8`0``Z&G]___TBQPDPV:0
M9I"+'"3#9I!FD&:09I!FD&:0Z.````"!PO^;``"-BC0!``"-@C0!```YR'0=
MBX)<````A<!T$U6)Y8/L%%'_T(/$$,G#+HUT)@##C;0F`````.B@````@<*_
MFP``58GE4XV*-`$``(V"-`$``(/L!"G(B</!Z!_!^P(!V-'X=!2+DFP```"%
MTG0*@^P(4%'_TH/$$(M=_,G#+HVT)@````"058GE4^A7____@<-KFP``@^P$
M@+LT`0```'4HBX,0`0``A<!T$H/L#/^S(`$``/^3$`$``(/$$.@T____QH,T
M`0```8M=_,G#+HVT)@````#I6____XL4),-FD&:09I!FD&:09I!FD&:09I!F
MD&:0D%6)P8GE5^A\'@``@<?YF@``5E.#[!R)5=R+A[0```")?>2+`(7`#X23
M````#[81A-)T!8#Z/750,?^+&(7;=#J)3>")QHE%V(G8B?.)QF:0@^P$5_]U
MX%:+1>3_D.P```"#Q!"%P'4&@#P^/70RBW,$@\,$A?9UV(GSC67TB=A;7E]=
MPXUT)@")R@^V6@&#P@&$VW0%@/L]=?`IRHG7ZYJ+1=B)\8G>C5PY`2G&BT7<
MP?X"B3"-9?2)V%M>7UW#,=OKMRZ-M"8`````+HUT)@!5B>56Z*H=``"!QBN:
M``!3@^QX98L=%````(E=](G#C4644%/_EM0```"#Q!"%P'4WBU6D@>(`\```
M@?H`0```=`B!^@"@``!U((/L"&H"4_^6:````(/$$(7`#Y3`#[;`ZP<NC70F
M`#'`BU7T92L5%````'4'C67X6UY=P^C>+P``+HVT)@````"-M@````!5B>57
M5N@9'0``@<::F0``4X'LC````&6+'10```")7>2)PX7;=`6`.P!U'(M%Y&4K
M!10````/A6$!``"-9?1;7E]=PXUT)@"#[`Q3_Y9X````B<>#Q!"%P'31@^P,
M5_^6E````(/$$(7`#X3@````@'@3+HU0$W4'@'H!`'3<D(!X$RX/A.8```"#
M[`R)E7#___]3_Y:@````BY5P____B85T____B10DB95L_____Y:@````BXUT
M____C4P!`HD,)(F-</____^6P````(F%=/___UB-AB2A__]:BY5L____4E-0
MBXUP____46H"_[5T_____Y;D````C46$@\084/^U=/____^6<````(/$$(/X
M_W0/BT64)0#P```]`$```'1L@^P,_[5T_____Y:D````@\00@^P,_[5T____
M_Y9D````@\00Z0[___^-=@"#[`Q7_Y:X````B1PD_Y;,````@\00Z<'^__\N
MC70F`(!Z`2X/A1#___^`>@(`#X37_O__Z0'___^-M"8`````BX5T____Z&7^
M___KF>@N+@``+HVT)@````"-M@````!5B>57B<<QP%;H91L``('&YI<``%.#
M[$B`.CT/E,")==1EBQT4````B5WDB=,!PU/_EJ````"-5>"#Q!")1<R)^.BJ
M_/__A<`/A#(!``"#[`R)QE"+3=3_D:````"+5<R#Q!`YT`^#]0```(M%X(MU
MU,'@`HE%R(N&M````(E%T`^V!X3`#X3-`0``/#T/A,4!``")^"Z-M"8`````
MC78`#[90`8/``832=`6`^CUU\"GXBU7,BTW0@^P,BW7(C400`@,Q4(M%U/^0
MP````(D&@\00A<!T:(M-T(MUR(L!C4\!BQ0P#[8'B`(\/70UA,!U(NLOZQHN
MC;0F`````"Z-M"8`````+HVT)@````!FD#P]=`\/M@&#P@&#P0&(`H3`=>W&
M`CTQP"Z-M"8`````#[8,`XA,`@&#P`&$R77QBT7D92L%%`````^%'@$``(UE
M]%M>7UW#+HVT)@````"0,<`NC;0F`````(VV``````^V%`.(%`:#P`&$TG7R
MZ[^+1=2+@+0```"+$(E%T(LRA?8/A,<````Q]HVV`````(GP@\8!BPRRA<EU
M](T$A0P```")1<2+1=2+B#@!``"%R75EBT74@^P,B57`QX`X`0```0```/]U
MQ/^0P````(/$$(7`#X15____C12U`````(E5R/]UQ%*+5<!24(E%Q(M%U/^0
M_````(M%T(M-Q(/$$(D(QT2Q!`````")=>#I7/[__XUT)@"#[`C_=<12_Y`X
M````B<&+1="#Q!")"(7)#X3X_O__C02U`````(E%R.O!+HUT)@`QP.E3_O__
MQT7$"````#'VZ4G____HKBL``"Z-M"8`````C;8`````58GE5U93@>P`$```
M@PPD`(/L,.C;&```@<9<E0``B974[___B<.-O>3O__]EH10```")1>0QP(V&
M*J'__VC_#P``5U#_EM@```"#Q!"%P'X3B<*-0/^`O!7C[___`'5`A<!U,(N&
M@````(/L!/^UU.___U-E_S#_EDP```"#Q!"+1>1E*P44````=4N-9?1;7E]=
MPXG"+HVT)@````!FD(/L!%*)E=#O__]J+U?_EN@```"#Q!"%P'2JBY70[___
MBX:`````4E=39?\P_Y:L````@\00ZZGHQ"H``(UT)@!5B>564^AV^/__@<.*
ME```B[.`````C8.`X?__4(V#.:'___^SA````%!E_S;_D_@```!8C8/DHO__
M6FH`4%"-@WR`__]0C8-5H?__4&7_-O^3C````(/$((UE^%M>7</HIA<```4O
ME```58GE@^P(C9"`X?__4HV0.:'___^PA````%*+D(````!E_S+_D/@```"#
MQ!#)PRZ-M"8`````58GE5U93@>P`$```@PPD`('L`!```(,,)`"#["SHOO?_
M_X'#TI,``&6A%````(E%Y#'`C;7BW___C;WC[____Y,4````@^P(C9,UH?__
M4E"-@VJA__]0:`$0``!J`E;_D^0```"#Q!QH`!```%=6_Y/8````,=*#Q!"%
MP'A!@^P,C4@!B<91B8W4W____Y/`````B<*#Q!"%P'0CBXW4W___45974(F%
MU-____^34````(N5U-___X/$$,8$,@"+1>1E*P44````=0J-9?2)T%M>7UW#
MZ$8I``"-M@````#I&____RZ-M"8`````C78`58GE5U93@>P`$```@PPD`('L
MG````.C5]O__@</ID@``BT4(B85T[___C8V$[___B<J-@WBA__]EBST4````
MB7WDBWT,B8UH[___Z+#W__^#[`AJ+XG&_[5T[____Y,\````@\00A<!T-HNU
M=.___XV#@:'__XGRZ)/Z__^)\(M5Y&4K%10````/A<,!``"-9?1;7E]=PRZ-
MM"8`````D(/L#%?_DP0!``!:68V+CJ'__XF-<.___U%0_Y/0````C8N0H?__
MB<>-@YFB__^#Q!")A63O__^%_W2/@#\`B8U@[___#X0+`0``C;8`````A?9T
M%H/L"%=6_Y,,`0``@\00A<`/A,0```"#[`Q7_Y.@````B<*-1`?_@\00.<=R
M&>LK+HVT)@`````NC70F`,8``(/H`3G'=`6`."]T\8/L#%?_DZ````")PH/$
M$(F5;.___X/L#/^U=.____^3H````(N5;.___XU$`@&#Q!`]_P\```^'[_[_
M_X/L!/^U=.____^U8.___U>-O>3O____M63O__]H`!```&H"5_^3Y````(/$
M&/^U:.___U?_DW````"#Q!"%P'42BX64[___)0#P```]`(```'12@^P(_[5P
M[___:@#_D]````")QX/$$(7`#X1^_O__@#\`#X7[_O__A?9T!8`^+G02N@$`
M``"-NW:A___I0/___V:0@'X!`'2XZ^8NC;0F`````(/L"&H!5_^3:````(/$
M$(7`=9N)^HV#@:'__^C0^/__@^P,5_^3!`$``(/$$.DM_O__Z-DF```NC;0F
M`````)!5B>56Z!H4``"!QIN0``!3BUT(@^P(:B]3_Y94````@\00A<!T`XU8
M`8E="(UE^(GP6UY=_Z`$`0``C;8`````58GE5U93@>P`$```@PPD`(/L+.@M
M]?__@<),D```98LU%````(EUY(MU"(7V#X2]````@#X`#X2T````@^P,5HF5
MU.____^2H````(UX`8/$$('_`!````^'X@```(/_!(N5U.___XV=Y.___P^#
MI0```(7_#X7-````C40#_SG#<A?K&BZ-M"8`````C78`Q@``@^@!.=AT!8`X
M+W3Q@^P(:B]3B974[____Y)4````BY74[___@\00A<!T,CG#<G:#[`Q3_Y($
M`0``@\00BU7D92L5%`````^%D````(UE]%M>7UW#+HVT)@````"0BT7D92L%
M%````'5SC8)VH?__B44(C67T6UY?7?^B!`$``(VV`````(M,/OR)C#W@[___
MB<&)W\'I`O.EZ4K___^-M"8`````Q@``ZX6-=@`QP.N+C70F``^V#HB-Y.__
M__?'`@````^$'O___P^W3#[^9HF,/>+O___I#/___^@<)0``+HVT)@````"-
M="8`Z%H2``"!P=^.``!5B>575E.-L9*A__^#[#R)3=2+N;0```!EBQT4````
MB5WDC5W@B=J)\.BG\___A<!T+(M5X(L'C020BU`$B1"%TG3B9I"+4`B#P`2)
M$(72=?2)VHGPZ'OS__^%P'74BT74B[BT````C;";H?__B=J)\.A?\___A<!T
M-(M5X(L'C020BU`$B1"%TG3B+HVT)@````!FD(M0"(/`!(D0A=)U](G:B?#H
M*_/__X7`=<R+1=2+N+0```"-L*.A__^)VHGPZ`_S__^%P'0TBU7@BP>-!)"+
M4`2)$(72=.(NC;0F`````&:0BU`(@\`$B1"%TG7TB=J)\.C;\O__A<!US(M%
MU(NXM````(VPK*'__XG:B?#HO_+__X7`=#2+5>"+!XT$D(M0!(D0A=)TXBZ-
MM"8`````9I"+4`B#P`2)$(72=?2)VHGPZ(OR__^%P'7,BT74C8BSH?__B["T
M````B4W0BT70B=KH:_+__X7`=#&+5>"+!HT$D(M0!(D0A=)TX8VV`````(M0
M"(/`!(D0A=)U](M%T(G:Z#KR__^%P'7/BT74B[BT````C;##H?__B=J)\.@>
M\O__A<!T,XM5X(L'C020BU`$B1"%TG3B+HVT)@````"0BU`(@\`$B1"%TG7T
MB=J)\.CK\?__A<!US8M%U(V(>*'__XNPM````(E-S(M%S(G:Z,OQ__^%P'0Q
MBU7@BP:-!)"+4`2)$(72=.&-M@````"+4`B#P`2)$(72=?2+1<R)VNB:\?__
MA<!USXM%U(V(SZ'__XNPM````(E-Q(M%Q(G:Z'KQ__^%P'0PBU7@BP:-!)"+
M4`2)$(72=.$NC70F`(M0"(/`!(D0A=)U](M%Q(G:Z$KQ__^%P'70BT74C8C9
MH?__B["T````B4W(BT7(B=KH*O'__X7`=#"+5>"+!HT$D(M0!(D0A=)TX2Z-
M="8`BU`(@\`$B1"%TG7TBT7(B=KH^O#__X7`=="+1=2+N+0```"-L..A__^)
MVHGPZ-[P__^%P'0SBU7@BP>-!)"+4`2)$(72=.(NC;0F`````)"+4`B#P`2)
M$(72=?2)VHGPZ*OP__^%P'7-BT74B[BT````C;"!H?__B=J)\.B/\/__A<!T
M-(M5X(L'C020BU`$B1"%TG3B+HVT)@````!FD(M0"(/`!(D0A=)U](G:B?#H
M6_#__X7`=<R+1=2)VHV`[:'__^A'\/__A<!T"HG"BT7(Z$GS__^+?=2)VHV'
M_J'__^@I\/__A<!T#8G"C8<0HO__Z"CS__^+1=2)VHV`&Z+__^@(\/__B<*%
MP'0LBT7,Z`KS__^+1>1E*P44````=3B+1=2-D#RB__^+1="#Q#Q;7E]=Z>;R
M__^+1=2)VHV`*Z+__^C&[___A<!TR(G"BT7$Z,CR___KO.CA(```D.@F#@``
M!:^*``!5B>6#[!AEBQ44````B57TC57PC8#/H?__Z(CO__^%P'0D#[80@/HP
M#Y3`A-(/E,()T(/P`0^VP(M5]&4K%10```!U!LG#,<#K[NB'(```C;0F````
M`%6)Y5/H-^[__X'#2XH``(U%#(/L!%#_=0AJ`HN#F````/\P_Y-T````QP0D
M_P```/^3%`$``"Z-M"8`````9I!5B>575E.-G"0``/__@>P`$```@PPD`#G<
M=?*#["SHW>W__X'#\8D``(F%U/_^_XG&9:$4````B47D,<!J`FH`:@!6_Y,(
M`0``C8W<__[_@\#_@]+_B87(__[_B=>)E<S__O_!_Q^)_C'P*?`QTB7__P``
M,?HQ\"GPB[7(__[_&?J+O<S__O\IQAG7@\00A?\/B/(````NC;0F`````&:0
MB8W(__[_:@!75O^UU/_^__^3"`$``(N-R/_^_R'0@\00@_C_#X3B````@^P$
M:`@``0!1B8W(__[__[74__[__Y-8````BXW(__[_@\00@_C_#X2:````@_@'
M=G"-1`'X.<AR:(FUR/_^_XT5)`$``(F]S/_^_^L/+HVT)@````"#Z`$YR'(Y
MBSP:.3AU\HNS*`$``#EP!'7GB[7(__[_*<B+O<S__O^9`?`1^HM-Y&4K#10`
M``!U;XUE]%M>7UW#B[7(__[_B[W,__[_@<8``/__@]?_B?")^C4``/__]]()
MT`^%&/___[C_____B<+KNXM%Y&4K!10```!U*H/L#(V#2Z+__U#H%/[__XM%
MY&4K!10```!U#X/L#(V#/J+__U#H^?W__^AT'@``C70F`%6)Y5/H)^S__X'#
M.X@``(/L!/^3L````(/L#%#_DZ@```"#Q!"%P'0"BP"+7?S)PU6)Y5?HC@L`
M`(''"X@``%93@^PLBT4(B474C;=7HO__B?!EBQ44````B57DC57@Z-SL__^%
MP'0'@#@`B<-U(8M%Y&4K!10````/A84```"+5=2-9?2)\%M>7UWIP.___X/L
M#/]UU/^7H````(E%T(D<)/^7H````(M5T(U4`@*)%"2)5=#_E\````"#Q`R)
MP8V'CJ'__U-0C8>9HO___W744(M5T%)J`E&)3=3_E^0```"+3=2#Q""+1>1E
M*P44````=1"-9?2)\(G*6UY?7>E,[___Z&<=``"-M"8`````58GE5^BN"@``
M@<<KAP``5E.![`P!``"+10B)A03___]EH10```")1>2-AVZB___'18P`````
MQT6P`````,=%F`````")182-AW:A__^)18B-APFB__^)1:"-AW.B__^)1:2-
MAR:B__^)1:B-AWNB__^)1:R-AW^B__^)19"-AX2B__^)192-A23___^)A13_
M__^)PHV'>*'__XF%`/___^B+Z___A<!T"X`X`(G##X4<!0``_Y>P````@^P,
M4/^7J````(/$$(7`#X11!```BS"%]@^$1P0``(/L#%;_EZ````"-7``!@\00
M@^P,4_^7P````(G!#[8&@\00B9T,____B8WX_O__A,!T98V7C:+__XF5"/__
M_XGRB<Z-="8`@^P,B940____4/^U"/___U-J`E;_E^0```"+E1#___^+A0S_
M__^#P@&)P8/$(#G8<P*)V8G(*=B#P`(YR',"B<@IRX/&`HU<`_X/M@*$P'6O
MC5V<C8<0HO__ZPZ-="8`BT,$@\,$A<!T-HN5%/___^B;ZO__B<:%P'3E@#@`
M=.#H6^O__X7`=->#[`Q6_Y<$`0``B<.#Q!"%P'4OC70F`(UUA(L>A=MT(H`[
M``^$/@,``(G8Z"?K__^%P`^%_P```(M>!(/&!(7;==Z#[`Q3_Y>@````6O^U
M^/[__XG&_Y>@````C;0&!`0``(FU#/___XDT)/^7P````(F%$/___XG!C8>2
MHO___[7X_O__4(V'D*'__XF%"/___U"-AY>B__]34%:)SFH"4?^7Y````(/$
M*&C``0``5O^7&````(/$$(/X_W41_Y<0````BP"#^!$/A3,#``"#[`C_M13_
M____M1#_____E]0```")PX/$$(7`=&J#[`S_M1#___^+A03_____,(V'3*/_
M_U`Q]HN'F````&H"_S#_ERP```"#Q""+1>1E*P44````#X6W!```C67TB?!;
M7E]=PXUV`(/L#(/&!%/_EP0!``")PX/$$(7`#X3)_O__Z>S^__^0BX4T____
M)0#P```]`$```'6$B[4\_____Y>P````.<8/A7#___^+A33___\E_P$``#W`
M`0``#X5:____@^P,_[4,_____Y?`````BY44____B<:-AV*B___HTNC__X/$
M$(7`#X27`@``@^P(4(N%!/____\PZ+;P__^#Q!")A?C^__^%P`^$=0(``(/L
M#/^U^/[___^7H````(G"@\00@_@#=DR#[`B-AZ"B__]0BX7X_O__B97T_O__
MC400_%#_EPP!``"#Q!"%P'4DBY7T_O__@_H$#X1+`P``BX7X_O__@'P0^R\/
MA#H#``"-="8`BY44____C8?/H?__B844____Z"GH__^%P`^$"0(```^V`(3`
M#X3^`0``/#`/A/8!``"+A13___^-ESRB___H#>O___^7%````(V/Y*+__XF-
M%/___U%0C8?$HO___[4(_____[40____4/^U#/___VH"5O^7Y````(V'TJ+_
M_X/$((F%!/___^M)C;8`````_Y<0````@S@1=4__EQ0```"#PP&#[`S_M13_
M__]34/^U"/____^U$/____^U!/____^U#/___VH"5O^7Y````(/$,(/L"&C`
M`0``5O^7&````(/$$(/X_W2F@^P,_[40_____Y=D````BX4`____B?+H2NK_
M_XDT).@B^O__@\00Z;W]__\NC;0F`````&:0,=OIU/S__RZ-M"8`````D(U=
MD"Z-M"8`````+HUT)@"+`X7`=!Z+E13____H[^;__X7`=`6`.`!U1HM#!(/#
M!(7`=>*#[`R-MV>B__^[#0```&H-_Y?`````B<&#Q!")A?C^__^X4P```,>%
M#/___PT```#I@_O__XVT)@````"#[`R#PP10_Y<$`0``@\00A<!TC(G&Z2[[
M__^#[`A0_[40____BX4$_____S"-AQ"C___IY?S__RZ-M"8`````@^P,4.A'
M^?__@\00BT7D92L%%`````^%G@$``(E="(UE](GX6UY?7?^@!`$``&:0BX4$
M____BP")A?C^___I>/W__RZ-="8`@^P(:@#_M?C^____ER@```"#Q!"%P`^$
M[OW__XF%!/___^CA]O__B87X_O__B97\_O__A=(/B,_]__^#P/9J`(/2_U)0
MBXT$____4?^7"`$``(U%M8/$#&H&4(N-!/___U'_EU@```"+C03___^#Q!"#
M^`8/A?T```"!?;4`0T%##X6#_?__9H%]N4A%#X5W_?__:@"+A?C^__^-7;N+
ME?S^__^#P,Z#TO]24%&)C13_____EP@!``"#Q`QJ*%.+C13___]1_Y=8````
M@\00@_@H#X6?````C8?DHO__QD7C`%"-A[6B__]3_[4(_____[40____4/^U
M#/___VH"5O^7Y````(/$(.FT_?__BX4$____BT@$A<D/A+G\__^#[`Q1B8T$
M_____Y>@````@\00@_@##X:=_/__@^P(C9>EHO__4HN-!/___XU$`?Q0_Y<,
M`0``@\00A<`/A7?\__^+C03___^)C?C^___I9OS__^C1%0``BT7D92L%%```
M`'7O@^P,C8>JHO__4.@V]?__C;8`````58GE5U:-?>!3B?KH8./__X'#='\`
M`(/L+&6+-10```")=>2+LX````!EBPX/MD%DB4W4B$%EC8.SH?__Z#_D__^%
MP'0,@#@QBTW4#X1O`0``Z$KP__]EBPZ-@^.B__]J`VH!4%'_DT@```"#Q!"%
MP'0P@^P$C9/EHO__4HM0#(E%U/\R9?\V_Y-,````BT74BT`,@\00BP#V0`I`
M#X5&`0``C8/JHO__:@-J`5!E_S;_DT@```"#Q!"%P(E%U'0PB?J-@X&A___H
ML^/__XM-U(G"BT$,BP"%T@^$\0```(/L!%)09?\V_Y-,````@\00@^P$C8/L
MHO__:@%09?\V_Y,@````C9,!H___@\0,4E!E_S;_DTP```!EBP:)^L9`90"-
M@WBA___H4^/__X/$$(F#/`$``(G&A<!T1(/L"&C``0``5O^3&````(U0`8/$
M$(/Z`78)@_@1#X6>````BT7D92L%%`````^%L0```(UE]%M>7UW#+HVT)@``
M``"0@^P,_[-``0``Z,+V__^#Q!")@SP!``")QH7`=9^+1>1E*P44````=7>#
M[`R-@Z"C__]0_Y/<````C;0F`````(!X`0`/A(_^___I@O[__Y"+DT`!``"+
M$N@SZ/__Z0[___^-M@````"#[`A09?\V_Y/$````@\00Z:7^__^+5>1E*Q44
M````=1=05HN#0`$``/\PC8/$H___4/^3W````.B+$P``+HVT)@````"-=@!5
MB>575HU5X%/H,N'__X'#1GT``(/L'&6+-10```")=>2+=0B-@\^A___H(>+_
M_X7`=!L/MA"$T@^4P(#Z,`^4P@C0=0F%]G0%@#X`=1J+1>1E*P44````=6R-
M9?1;7E]=PXVV`````(/L#%;H?^S__XG'6%IJ+U?_DU0```"#Q!"%P'0#C7@!
M@^P,5_^3!`$``(V3DJ+__X/$#&H$4E#_D^P```"#Q!"%P'6BBT7D92L%%```
M`'4.C67TB?!;7E]=Z>KB___HM1(``(L$),.+#"3#BS0DPXL\),-FD&:09I!F
MD&:09I!FD&:09I!FD)!5B>575HV-I/[__U.)PX'L?`$``(F%B/[__V6A%```
M`(E%Y#'`ZQDNC;0F`````"Z-M"8`````+HVT)@````"0BU2#'`_*B12!@\`!
M@_@0=>^+C:C^__^+M=C^__^-E:S^__^+O=S^__^+A>#^__^)C93^__^-3:R+
MG:3^__^)C8S^___K0.LX+HVT)@`````NC;0F`````"Z-M"8`````+HVT)@``
M```NC;0F`````"Z-M"8`````+HVT)@````")C93^__^)A9#^__^+"H/"!(M"
M%#'(,?")_HN]D/[__S'8BYV4_O__T<")0C0YE8S^__]URXN]B/[__XM'#(L/
MBU\0BW<$B864_O__BX6D_O__B;6,_O__BW<(C90#F7F"6HG(B[V4_O__B9UX
M_O__P<`%B?,!PHGPB[6,_O__B9V$_O__,?@A\,'.`C'XB<\!PHG8B;U\_O__
M,?`AR(N-J/[__S'8BYV4_O__C8P+F7F"6HN=A/[__P'(B='!P04!R(GYP<D"
MB<^)\8F]D/[__S'YB[VL_O__(='!R@(Q\8V\.YEY@EH!^8G'P<<%C1PYB[V0
M_O__B9V`_O__B?DQT2'!P<@",?F+O;#^__^-M#Z9>8):`?&)WL'&!8T\,8G1
MB[6T_O__,<$AV8N=D/[__S'1C9PSF7F"6HG^`=G!Q@6--#&)M9#^__^+M8#^
M___!S@*)\8G&,<Z)\XNUN/[__R'[P<\"C90RF7F"6HNUD/[__S'#`=J+G9#^
M___!Q@6--#*)RC'Z(=J+G;S^__\QRHV$&)EY@EH!T(GRP<(%`<*+A9#^__^)
ME8#^__^)^HN=P/[__\'(`C'"C8P9F7F"6B'RP<X",?H!RHN-@/[__\'!!8T<
M"HN-@/[__XG",?(ARHN-Q/[__S'"C8P/F7F"6HN]R/[__P'*B=G!P06-A#B9
M>8):`<J)\8F5D/[__XN5@/[__\'*`C'1(=G!RP(Q\0'(BXV0_O__P<$%C3P(
MBXV0_O__B=`QV"'(BXW,_O__,="-C`Z9>8):`<B)^<'!!8TT"(N%D/[__XG9
MB;6`_O__B[70_O__P<@",<&-E#*9>8):B[6`_O__(?G!SP(QV<'&!0'*BXV`
M_O__C30RB<(Q^B'*BXW4_O__,<*-C`N9>8):BYW8_O__`<J)\<'!!8V$&)EY
M@EH!RHGYB960_O__BY6`_O__P<H",=$A\<'.`C'Y`<B+C9#^___!P06-'`B+
MC9#^__^)T#'P(<B+C=S^__\QT(V,#YEY@EJ+O>#^__\!R(G9P<$%C90ZF7F"
M6@'(B?&)A8#^__^+A9#^___!R`(QP2'9P<L",?$!RHN-@/[__\'!!8T\"HN-
M@/[__XG",=HARHN-Y/[__S'"C8P.F7F"6@'*B?G!P06--`J+E8#^__^)V8FU
MD/[__XNUZ/[__\'*`C'1C80PF7F"6B'YP<\",=D!R(N-D/[__\'!!8TT"(N-
MD/[__XG0,?@AR(N-[/[__S'0C8P+F7F"6HN=\/[__P'(B?'!P06-E!J9>8):
M`<B+C9#^___!R0*)C9#^__\Q^2'Q,?D!T8G"P<(%`=&)\L'*`HG3BY7T_O__
MC;07H>O9;HN]D/[__XGZ,=HQPL'(`@'RB<[!Q@4!\HNU^/[__XV\-Z'KV6Z)
MWC'&,<[!R0(!_HG7P<<%`?Z)SXN-_/[__XV<"Z'KV6Z)P3'Y,='!R@(!V8GS
MP<,%`=F)TXN5`/___XV4$*'KV6Z)^#'8,?#!S@(!T(G*P<(%`="+E03___^-
MO!>AZ]ENB=HQ\C'*P<D"`?J)Q\''!0'ZB[T(____C;P[H>O9;HGS,<LQPP'[
MB=?!R`+!QP4!^XG'BX4,____C;0&H>O9;HG(,?@QT,'*`@'PB=[!Q@4!\(G6
MBY40____C901H>O9;HGY,?$QV<'+`@'1B<+!P@4!T8N5%/___XV\%Z'KV6Z)
M\C':,<+!R`(!^HG/P<<%`?J)QXN%&/___XV$!J'KV6Z)WC'^,<[!R0(!QHG0
MP<`%`<:+A1S___^-G`.AZ]ENB?@QR#'0`=B)\\'#!0'8P<H"B=.+E2#___^-
ME!>AZ]ENB<\QWS'WP<X"`=>)PL'"!0'7BY4D____C8P1H>O9;HG:,?(QPL'(
M`@'*B?G!P04!RHG!BX4H____C80#H>O9;HGS,<LQ^\'/`@'#B=#!P`4!PXN%
M+/___XVT!J'KV6Z)R#'X,=#!R@(!\(G>P<8%`?")UHN5,/___XV4$:'KV6Z)
M^3'Q,=G!RP(!T8G"P<(%`=&+E33___^-O!>AZ]ENB?(QVC'"P<@"`?J)S\''
M!0'ZB<>+A3C___^-A`:AZ]ENB=XQ_C'.P<D"`<:)T,'`!0'&BX4\____C9P#
MH>O9;HGX,<@QT,'*`@'8B?/!PP4!V(N=0/___XV\'Z'KV6Z)RS'3,?/!S@(!
M^XG'P<<%`?N)UXF=D/[__PGWB=,AQR'SP<@""?N+O43___^-C#G<O!N/`=F+
MG9#^___!PP6-/!F)\0G!B<N+C9#^__\ARXGQ(<$)V8N=2/___XV4&MR\&X\!
MRHGYP<$%`<J)P8F5@/[__XN5D/[__\'*`@G1B<N)P2'[(=$)V8N=3/___XV<
M'MR\&X^+M8#^__\!V8N=@/[__\'&!8TT,8GYB=>)M9#^___!R0*)UB'/"<XA
MWHG["?.+M5#___^-A##<O!N/B[60_O__`=B+G9#^___!Q@6-/#"+A8#^__^)
MSL'(`@G&(=Z)RR'#"?.+M53___^-E#+<O!N/B?X!VL'&!8G#C30RBY60_O__
MB;6`_O__B<;!R@()UB'3(?X)\XNU6/___XV,,=R\&X^+M8#^__\!V8N=@/[_
M_\'&!8TT,8GYB=>)M9#^___!R0*)UB'/"<XAWHG["?.+M5S___^-A##<O!N/
MB[60_O__`=B+G9#^___!Q@6-/#"+A8#^__^)SL'(`@G&(=Z)RR'#"?.+M6#_
M__^-E#+<O!N/B?X!VL'&!8G#C30RBY60_O__B;6`_O__B<;!R@()UB'3(?X)
M\XNU9/___XV,,=R\&X^+M8#^__\!V8N=@/[__\'&!8TT,8GYB=?!R0*)M9#^
M__^)UB'/"<XAWHG["?.+M6C___^-A##<O!N/B[60_O__`=B+G9#^___!Q@6-
M/#"+A8#^__^)SL'(`@G&(=Z)RR'#"?.+M6S___^-E#+<O!N/B?X!VL'&!8G#
MC30RB;6`_O__BY60_O__B<;!R@()UB'3(?X)\XNU</___XV,,=R\&X^+M8#^
M__\!V8N=@/[__\'&!8TT,8GYB=>)M9#^___!R0*)UB'/"<XAWHG["?.+M73_
M__^-A##<O!N/B[60_O__`=B+G9#^___!Q@6-/#"+A8#^__^)SL'(`@G&(=Z)
MRR'#"?.+M7C___^-E#+<O!N/B?X!VL'&!8G#C30RBY60_O__B;6`_O__B<;!
MR@()UB'3(?X)\XNU?/___XV,,=R\&X^+M8#^__\!V8N=@/[__\'&!8TT,8GY
MB=>)M9#^___!R0*)UB'/"<XAWHG["?.+=8"-A##<O!N/B[60_O__`=B+G9#^
M___!Q@6-/#"+A8#^__^)SL'(`@G&(=Z)RR'#"?.+=82-E#+<O!N/B?X!VL'&
M!8G#C30RBY60_O__B;6`_O__B<;!R@()UB'3(?X)\XMUB(V,,=R\&X^+M8#^
M__\!V8G3P<8%C30QB?F+O8#^___!R0*)M9#^__^)U@G.(<LA_@GSBW6,C80P
MW+P;CXNUD/[__P'8P<8%`?")_HG/P<X"B?,)]XNUD/[__R'WB<XAW@G^BWV0
MC90ZW+P;CP'6B<+!P@4!UHN5D/[__\'*`HG7BU64C901UL%BRHG9,?DQP<'(
M`@'1B?+!P@4!T8M5F(V<$];!8LJ)^C'",?+!S@(!VHG+P<,%`=J+79R-O!_6
MP6+*B<,Q\S'+P<D"`?N)U\''!0'[BWV@C;PXUL%BRHGP,<@QT,'*`@'XB=_!
MQP4!^(G7BU6DC906UL%BRHG.,?XQWL'+`@'6B<+!P@4!UHM5J(V,$=;!8LJ)
M^C':,<+!R`(!RHGQP<$%`<J)P8M%K(V$!];!8LJ)WS'/,??!S@(!QXG0P<`%
M`<>+1;"-G`/6P6+*B<@Q\#'0P<H"`=B)^\'#!0'8B=.+5;2-E!'6P6+*B?$Q
MV3'YP<\"`=&)PL'"!0'1BU6XC;06UL%BRHG:,?HQP@'RB<[!Q@7!R`(!\HG&
MBT6\C80#UL%BRHG[,?,QR\')`@'#B=#!P`4!PXM%P(V\!];!8LJ)\#'(,=#!
MR@(!^(G?P<<%`?B)UXM5Q(V4%M;!8LJ)SC'^,=[!RP(!UHG"P<(%`=:+5<B-
MC!'6P6+*B?HQVC'"P<@"`<J)\<'!!0'*B<&+1<R-A`?6P6+*B=\QSS'W`<>)
MT,'`!0''BT70P<X"C9P#UL%BRHG(,?`QT,'*`@'8B?O!PP4!V(G3BU74C901
MUL%BRHGQ,=DQ^<'/`@'1B<+!P@4!T8M5V(VT%M;!8LJ)VC'Z,<+!R`(!\HG.
MP<8%`?*+==R-M#/6P6+*B?LQPS'+P<D"`?.)UHF-D/[__XN-?/[__\'&!0'S
MBW7@C;0QUL%BRHG!`?>+M9#^__\Q\8G.B=DQUL'!!0'^B[V(_O__`<Z)-XNU
MC/[__P'SP<H"B5\$BYV$_O__`=J+G93^__^)5PB+E9#^__\!VHE7#(N=>/[_
M_P'8B4<0BT7D92L%%````'4+@<1\`0``6UY?7</HF00``"Z-M"8`````D.C6
M\?__!5]N``!5B>6#[!1J8/^0P````,<``2-%9\=`!(FKS>_'0`C^W+J8QT`,
M=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````#)PRZ-M"8`````C;0F
M`````.AZ\?__@<'_;0``58GE5U93@^P<BWT(BW40BU<8C03U``````-'%(U?
M'(E'%(GP@](`P>@=`=")1QB+1UR%P`^%4P$``(/^/P^.O@```(U&P,'N!HE]
M"(G?C4[_P>8&B47@B4WDBTT,`?&+=0R)\XG.+HVT)@````"-M"8`````BP.#
MPT")!XM#Q(E'!(M#R(E'"(M#S(E'#(M#T(E'$(M#U(E'%(M#V(E'&(M#W(E'
M'(M#X(E'((M#Y(E')(M#Z(E'*(M#[(E'+(M#\(E',(M#](E'-(M#^(E'.(M#
M_(E'/(M%".BW\/__.?-UDXM%X(M-#(G[BU7DBWT(B<:#X,"-1`%`P>(&B44,
M*=:#_@1R7XM%#(L`B4<<BT4,BT0P_(E$,_R-1R"+50R#X/PIPRG:`?.#X_R#
M^P1R)8EU$(/C_#')BS0*B30(@\$$.=ER\XMU$"Z-M"8`````+HUT)@")=UR-
M9?1;7E]=PRZ-="8`A?9T[(M%#`^V`(A''/?&`@```'3;BT4,#[=$,/YFB40S
M_NO,C70F`+I`````*<(Y\G\]C5\<@^P$`=A2B57D_W4,4/^1G````(M'7(M5
MY`'0@\00B4=<@_A`=9>)^`%5#"G6Z,CO___I:/[__XUV`(GRZ[\NC;0F````
M`(UT)@#HAN___P4/;```58GE5U93@^P<BUT,BW4(B47DBT,4BU,8B<?!Z`,/
MRHE5W(/@/P_/B7W@C7L<C5`!QD0#'("-!!>#^C@/CO4```"Y0````"G1=!LQ
MTO;!`0^%@0$``,8$$`#&1!`!`(/"`CG*<O")V.@Z[___C5<$QT,<`````#'`
M@^+\QT<T`````"G7C4\XB=?!Z0+SJXM%W(E#5(M%X(E#6(G8Z`7O__^+`\'H
M&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(
M1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,
MB&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A.+1>2)70B#Q!Q;
M7E]=_Z!D````D+DX````*=&#^01R=(U0!,<``````(/B_,=$"/P`````*=`!
MR(/@_(/X!`^"*/___XG!OP0```"#X?R)3=B-2/_!Z0+'`@````"#X0$YQP^#
M!/___X7)=6#'!#H`````QT0Z!`````"+1=B#QP@YQW+GZ>+^__\NC;0F````
M`&:0A<D/A-#^___&``#VP0(/A,3^__\QTF:)5`C^Z;C^__^Z`0```,8``#G*
M#X)O_O__Z7K^__^-=@#'0@0`````BT78OP@````YQW*-Z8C^___H=NW__P7_
M:0``58GE@^P(_[`@`0``_W40_W4,_W4(_Y!`````R<-FD&:09I!FD)#H1NW_
M_P7/:0``58GE@^P(_Y#(``````!3@^P(Z)_-__^!P[-I``"#Q`A;PP``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F
M86EL960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S
M:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V
M,P`M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S
M:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,
M15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?
M<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B
M(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM
M>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[
M("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I
M>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A
M9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I
M.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P
M*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*
M?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@
M/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I
M;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE
M.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)
M3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'
M24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H
M;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T
M(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D
M(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA
M9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN
M9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G
M:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@
M)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O
M=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B
M=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U
M:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z
M:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#
M86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D
M960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P
M87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*
M:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D
M9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A
M8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN
M72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT
M<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q
M=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I
M<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*
M979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T[
M"F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER
M92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/
M.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T
M9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A
M<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM
M>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P
M=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M
M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W
M=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D
M14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H
M)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B
M8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`]
M(#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO
M<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C
M;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@
M/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?
M9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L
M971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[&`$``"(```"P
M?___8`$``-!___]D!0``,(+__S0!``!P@___A`$``$"$___$`0``T(3___`!
M``"`AO__(`(```")__]4`@``X(G__X0"``!`BO__K`(``("*___,`@``8(O_
M__P"``!PB___$`,``-"-__]``P``$([__V@#``"0C___J`,``,"3___8`P``
M()3___P#``!@E/__&`0``#"6__](!```8);__VP$``!`E___K`0``/">___P
M!```(*'__R0%``#KH?__K`4``.^A___`!0``\Z'__]0%``#WH?__Z`4``!"B
M___\!0``$+#__RP&``!PL/__3`8``&"R__]\!@``<+3__ZP&``"@M/__S`8`
M`!0``````````7I2``%\"`$;#`0$B`$'"!`````<````](#__RP`````````
M%``````````!>E(``7P(`1L,!`2(`0``(````!P```!(?O__(``````."$8.
M#$H/"W0$>``_&CLJ,B0B/````$````#D@?__PP````!!#@B%`D0-!4&'`U"&
M!(,%`FH*PT'&0<=!Q0P$!$4+<PK#0<9!QT'%#`0$00L``"@```"`````=(+_
M_X(`````00X(A0)"#05!A@-/@P0"9PK#0<9!Q0P$!$$++````*P```#8@O__
MH@$```!!#@B%`D(-!4*'`X8$4H,%:0K#0<9!QT'%#`0$10L`,````-P```!8
MA/__<@(```!!#@B%`D(-!4&'`T6&!$^#!0,[`0K#0<9!QT'%#`0$2@L``"P`
M```0`0``I(;__]P`````00X(A0)"#050AP.&!(,%`GT*PT'&0<=!Q0P$!$$+
M`"0```!``0``5(?__V``````00X(A0)"#05"A@.#!`)8PT'&0<4,!`0<````
M:`$``(R'__\X`````$L."(4"0@T%:L4,!`0``"P```"(`0``K(?__]H`````
M00X(A0)"#05:AP.&!(,%`K0*PT'&0<=!Q0P$!$$+`!````"X`0``7(C__P4`
M````````+````,P!``!8B/__5P(```!!#@B%`D(-!5.'`X8$@P4"?0K#0<9!
MQT'%#`0$2@L`)````/P!``"(BO__.@````!!#@B%`D(-!4&&`TR#!&+#0<9!
MQ0P$!#P````D`@``H(K__W0!````00X(A0)"#050AP.&!(,%`M`*PT'&0<=!
MQ0P$!$H+60K#0<9!QT'%#`0$3`L````L````9`(``."+__\O!````$P."(4"
M0@T%0X<#A@2#!0/Q`PK#0<9!QT'%#`0$10L@````E`(``."/__]9`````$L.
M"(4"0@T%`D(*Q0P$!$$+```8````N`(``!R0__\V`````$$."(4"0@T%08,#
M+````-0"``!`D/__S`$```!!#@B%`D(-!4.'`X8$@P4#5@$*PT'&0<=!Q0P$
M!$$+(`````0#``#@D?__,`````!!#@B%`D(-!4&#`VO%PPP$!```/````"@#
M``#LD?__V0````!!#@B%`D(-!4&'`U"&!(,%`D0*PT'&0<=!Q0P$!$4+`FP*
MPT'&0<=!Q0P$!$4+`$````!H`P``C)+__ZH'````00X(A0)"#05!AP-3A@2#
M!0/"`@K#0<9!QT'%#`0$1`L#%0,*PT'&0<=!Q0P$!$@+````,````*P#``#X
MF?__)0(```!!#@B%`D(-!4*'`X8$1H,%`V@!"L-!QD''0<4,!`1*"P```#P`
M``#@`P``])O__\L`````00X(A0)"#05&AP.&!(,%`E4*PT'&0<=!Q0P$!$<+
M`E8*PT'&0<=!Q0P$!$4+``!$````(`0``&1Z__]5`@```$0,`0!)$`4"=0!!
M$`<"=7Q$$`8"=7@0`P)U=$P/`W5P!@-O`0K!#`$`0<-!QD''0<5##`0$00L0
M````:`0``#><__\$`````````!````!\!```)YS__P0`````````$````)`$
M```7G/__!``````````0````I`0```><__\$`````````"P```"X!```#)S_
M__<-````00X(A0)"#05)AP.&!(,%`^(-"L-!QD''0<4,!`1!"QP```#H!```
MW*G__U$`````2PX(A0)"#04"0\4,!`0`+`````@%```<JO__Y`$```!,#@B%
M`D(-!4:'`X8$@P4#4P$*PT'&0<=!Q0P$!$8++````#@%``#<J___$`(```!+
M#@B%`D(-!4:'`X8$@P4#(P$*PT'&0<=!Q0P$!$<+'````&@%``"\K?__)P``
M``!+#@B%`D(-!5G%#`0$```8````B`4``,RM__\6`````$L."(4"0@T%````
M``````0````0`````0```$=.50``````!`````0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````,`C``!P(P```0````8#```!````$0,``!T```"W
M!```#``````@```-````*%4``!D```"\O0``&P````0````:````P+T``!P`
M```$````]?[_;S0"```%````?`D```8```!\`P``"@```-H$```+````$```
M`!4``````````P```.2^```"````"````!0````1````%P```-@1```1````
MR`\``!(````0`@``$P````@````>````"````/O__V\!```(_O__;Q@/``#_
M__]O`0```/#__V]6#@``)````.`1```C````$````"4````$````````````
M````````````````````````````````````````````````````````Q+T`
M````````````-B``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$`@````````!,````I005(N<&T*`````.QB``!'0T,Z("A'3E4I
M(#$T+C(N,2`R,#(U,#(P-P``+G-H<W1R=&%B`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92YG;G4N<')O<&5R='D`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y
M;@`N<F5L+G!L=``N<F5L<BYD>6X`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM=&%G`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M````"P````<````"````U`$``-0!```D```````````````$`````````!X`
M```'`````@```/@!``#X`0``*```````````````!``````````Q`````0``
M``(````@`@``(`(``!,```````````````$`````````.0```/;__V\"````
M-`(``#0"``!(`0``!0`````````$````!````$,````+`````@```'P#``!\
M`P````8```8````!````!````!````!+`````P````(```!\"0``?`D``-H$
M``````````````$`````````4P```/___V\"````5@X``%8.``#`````!0``
M```````"`````@```&````#^__]O`@```!@/```8#P``L`````8````!````
M!`````````!O````"0````(```#(#P``R`\``!`"```%``````````0````(
M````>`````D```!"````V!$``-@1```(````!0```!<````$````"````($`
M```3`````@```.`1``#@$0``$```````````````!`````0```"+`````0``
M``8`````(````"```"````````````````0`````````?`````$````&````
M("```"`@```@```````````````0````!````)$````!````!@```$`@``!`
M(```YC0`````````````0`````````"7`````0````8````H50``*%4``!0`
M``````````````0`````````G0````$````"`````&````!@``!N0```````
M```````$`````````*4````!`````@```'"@``!PH```'`$`````````````
M!`````````"S`````0````(```",H0``C*$``-`%``````````````0`````
M````O0````<````"````7*<``%RG```@```````````````$`````````,L`
M```.`````P```+R]``"\K0``!```````````````!`````0```#7````#P``
M``,```#`O0``P*T```0```````````````0````$````XP````8````#````
MQ+T``,2M```@`0``!@`````````$````"````.P````!`````P```.2^``#D
MK@``'`$`````````````!`````0```#Q`````0````,`````P````+```!@`
M``````````````0`````````]P````@````#````&,```!BP```4````````
M```````$`````````/P````!````,``````````8L```&P``````````````
M`0````$````!`````P``````````````,[````4!``````````````$`````
#````
